#ifndef SERVOWIDGET_H
#define SERVOWIDGET_H

#include <QDial>
#include <QSpinBox>
#include <QVBoxLayout>
#include <QWidget>

#include "servoController.h"
#include "parameter.h"

class servoWidget : public QWidget {
	int number;
	servoController* controller;
	QSpinBox valBox;
	QDial dial;
	parameter minBox, maxBox;
	QLabel title;
	QVBoxLayout layout;
	Q_OBJECT
	public:
	servoWidget(int number_, servoController* controller_, int value = 0, QWidget *parent = 0) : QWidget(parent), 
			number(number_), 
			controller(controller_), 
			valBox(this),
			dial(this),
			minBox("min", 8000, 0, 65535, this),
			maxBox("max", 16000, 0, 65535, this),
			title(QString("Servo ") + QString::number(number), this)
	{
		dial.setValue(value);
		valBox.setMaximum(65535);
		valBox.setMinimum(0);
		valBox.setValue(value);
		layout.addWidget(&title);
		layout.addWidget(&valBox);
		layout.addWidget(&dial);
		layout.addWidget(&minBox);
		layout.addWidget(&maxBox);
		setLayout(&layout);
		connect(&minBox, SIGNAL(valueChanged(int)), this, SLOT(bordersChanged()));
		connect(&maxBox, SIGNAL(valueChanged(int)), this, SLOT(bordersChanged()));
		connect(&valBox, SIGNAL(valueChanged(int)), this, SLOT(stateChanged()));
		connect(&dial, SIGNAL(valueChanged(int)), &valBox, SLOT(setValue(int)));
		stateChanged();
		bordersChanged();
	}

	public slots:
		void bordersChanged(){
			dial.setMaximum(maxBox.value());
			dial.setMinimum(minBox.value());
		}
		void stateChanged(){
			controller->setServo(number, valBox.value());
			int v = valBox.value();
			if(v < minBox.value()){
				dial.setMinimum(v);
				minBox.setValue(v);
			}
			if(v > maxBox.value()){
				dial.setMaximum(v);
				maxBox.setValue(v);
			}
			dial.setValue(v);
		}
		
};

#endif
